/***************************************************************************
 * C style box comment.
 *
 * This function has a very pretty C style box comment.
 ***************************************************************************/
void boxcomm_c1(void);

/***************************************************************************
/ Fancier C style box comment.
/
/ This function has a very pretty C style box comment.
/***************************************************************************/
void boxcomm_c2(void);

/***************************************************************************
/*** Even Fancier C style box comment.
/***
/*** This function has a very pretty C style box comment.
/***************************************************************************/
void boxcomm_c3(void);

/*-------------------------------------------------------------------------
 * C style box comment.
 *
 * This function has a dashed C style box comment.
 *-------------------------------------------------------------------------*/
void boxcomm_c4(void);

////////////////////////////////////////////////////////////////////////////
// C++ style box comment.
//
// This function has a very pretty C++ style box comment.
////////////////////////////////////////////////////////////////////////////
void boxcomm_cpp1(void);

////////////////////////////////////////////////////////////////////////////
//// Fancier C++ style box comment.
////
//// This function has a very pretty C++ style box comment.
////////////////////////////////////////////////////////////////////////////
void boxcomm_cpp2(void);
